package com.yiqi.generator.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yiqi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yiqi.generator.mapper.GenFormMapper;
import com.yiqi.generator.domain.GenForm;
import com.yiqi.generator.service.IGenFormService;

/**
 * 单生成记录Service业务层处理
 *
 * @author xiaohei
 * @date 2023-07-23
 */
@Service
public class GenFormServiceImpl extends ServiceImpl<GenFormMapper,GenForm> implements IGenFormService {

    @Autowired
    private GenFormMapper genFormMapper;

    /**
     * 查询单生成记录
     *
     * @param id 单生成记录主键
     * @return 单生成记录
     */
    @Override
    public GenForm selectGenFormById(Long id) {
        return genFormMapper.selectGenFormById(id);
    }

    /**
     * 查询单生成记录列表
     *
     * @param genForm 单生成记录
     * @return 单生成记录
     */
    @Override
    public List<GenForm> selectGenFormList(GenForm genForm) {
        return genFormMapper.selectGenFormList(genForm);
    }

    /**
     * 新增单生成记录
     *
     * @param genForm 单生成记录
     * @return 结果
     */
    @Override
    public int insertGenForm(GenForm genForm) {
                genForm.setCreateTime(DateUtils.getNowDate());
            return genFormMapper.insertGenForm(genForm);
    }

    /**
     * 修改单生成记录
     *
     * @param genForm 单生成记录
     * @return 结果
     */
    @Override
    public int updateGenForm(GenForm genForm) {
                genForm.setUpdateTime(DateUtils.getNowDate());
        return genFormMapper.updateGenForm(genForm);
    }

    /**
     * 批量删除单生成记录
     *
     * @param ids 需要删除的单生成记录主键
     * @return 结果
     */
    @Override
    public int deleteGenFormByIds(Long[] ids) {
        return genFormMapper.deleteGenFormByIds(ids);
    }

    /**
     * 删除单生成记录信息
     *
     * @param id 单生成记录主键
     * @return 结果
     */
    @Override
    public int deleteGenFormById(Long id) {
        return genFormMapper.deleteGenFormById(id);
    }
}
